@@ -10,6 +10,7 @@
 #include "ircint.h"
 #include "utils.h"
 #include "cmd/root.h"
+#include "config.h"
 
 Auth_PUser   Auth_TUser  ::master = NULL;
 Auth_PUser   Auth_TUser  ::first  = NULL;
@@ -24,7 +25,7 @@ Auth_PUHCB   Auth_TUHCB  ::last   = NULL;
 Auth_TUser::Auth_TUser(const char *s_acct, const char *s_pass, TF s_master)
 {
 #ifdef DEBUG
-  fputs("DEBUG - Auth_TUser ctor called\n", stderr);
+  Util_Eputs("DEBUG - Auth_TUser ctor called\n");
 #endif
   if (last!=NULL) {
     prev = last;
@@ -53,13 +54,13 @@ Auth_TUser::Auth_TUser(const char *s_acct, const char *s_pass, TF s_master)
   *host = 0;
   if (s_master) {
     if (master!=NULL) {
-      fputs("Error: Multiple master accounts. Exiting.", stderr);
+      Util_Eputs("Error: Multiple master accounts. Exiting.");
       exit(255);
     }
     master = this;
   }
   if (GetUser(acct)!=this) {
-    fprintf(stderr, "Multiple account instances for %s\n", acct);
+    Util_Eprintf("Multiple account instances for %s\n", acct);
     exit(255);
   }
 }
@@ -69,7 +70,7 @@ Auth_TTicket::Auth_TTicket(const char *s_nick, const char *s_user,
 			   IRC_PCL s_chans)
 {
 #ifdef DEBUG
-  fputs("DEBUG - Auth_TTicket ctor called\n", stderr);
+  Util_Eputs("DEBUG - Auth_TTicket ctor called\n");
 #endif
   if (last!=NULL) {
     prev = last;
@@ -94,7 +95,7 @@ Auth_TTicket::Auth_TTicket(const char *s_nick, const char *s_user,
 void Auth_TUser::Delete(Auth_PUser user)
 {
 #ifdef DEBUG
-  fputs("DEBUG - Auth_TUser::Delete called\n", stderr);
+  Util_Eputs("DEBUG - Auth_TUser::Delete called\n");
 #endif
   if (user->prev!=NULL)
     user->prev->next = user->next;
@@ -107,19 +108,19 @@ void Auth_TUser::Delete(Auth_PUser user)
     last = user->prev;
   if (user->chans!=NULL) {
 #ifdef DEBUG
-    fputs("DEBUG - Flushing non-empty chans pointer.\n", stderr);
+    Util_Eputs("DEBUG - Flushing non-empty chans pointer.\n");
 #endif
     IRC_TCL::Flush(user->chans);
   }
   if (user->dcc_cookie!=NULL) {
     if (user->dcc_active) {
 #ifdef DEBUG
-      fputs("DEBUG - Closing non-empty DCC cookie.\n", stderr);
+      Util_Eputs("DEBUG - Closing non-empty DCC cookie.\n");
 #endif
       IRC_DCCChatClose(user->dcc_cookie);
     } else {
 #ifdef DEBUG
-      fputs("DEBUG - Rejecting non-empty DCC cookie.\n", stderr);
+      Util_Eputs("DEBUG - Rejecting non-empty DCC cookie.\n");
 #endif
       IRC_DCCChatReject(user->dcc_cookie);
     }
@@ -132,7 +133,7 @@ void Auth_TUser::Delete(Auth_PUser user)
 void Auth_TTicket::Delete(Auth_PTicket ticket)
 {
 #ifdef DEBUG
-  fputs("DEBUG - Auth_TTicket::Delete called\n", stderr);
+  Util_Eputs("DEBUG - Auth_TTicket::Delete called\n");
 #endif
   if (ticket->prev!=NULL)
     ticket->prev->next = ticket->next;
@@ -244,7 +245,7 @@ TF Auth_TUser::Login(const char *s_pass, const char *s_nick,
 		     const char *s_user, const char *s_host, IRC_PCL s_chans)
 {
 #ifdef DEBUG
-  fputs("DEBUG - Auth_TUser::Login called\n", stderr);
+  Util_Eputs("DEBUG - Auth_TUser::Login called\n");
 #endif
   if (strcmp(pass, s_pass)!=0)
     return FALSE;
@@ -261,7 +262,7 @@ TF Auth_TUser::Login(const char *s_pass, const char *s_nick,
 void Auth_TUser::Logout()
 {
 #ifdef DEBUG
-  fputs("DEBUG - Auth_TUser::Logout called\n", stderr);
+  Util_Eputs("DEBUG - Auth_TUser::Logout called\n");
 #endif
   *nick = 0;
   *user = 0;
@@ -280,9 +281,8 @@ void Auth_TUser::Logout()
 void Auth_TUser::AddTracking(const char *channel)
 {
   if (chans==NULL) {
-    fprintf(stderr, 
-	  "Error: Added a channel to tracking, but we're not tracking!\n\
-Channel: %s  Account: %s  Mask: %s@%s\n", channel, acct, user, host);
+    Util_Eprintf("Error: Added a channel to tracking, but we're not tracking!\
+\nChannel: %s  Account: %s  Mask: %s@%s\n", channel, acct, user, host);
     return ;
   }
   IRC_PCL temp;
@@ -351,7 +351,7 @@ void Auth_TTicket::ChangeTracking(const char *s_nick)
 void Auth_TUser::StartTracking(const char *channel, const char *s_nick)
 {
   if (chans!=NULL) {
-    fputs("Error: Old tracking list still present; deleting.\n", stderr);
+    Util_Eputs("Error: Old tracking list still present; deleting.\n");
     IRC_TCL::Flush(chans);
   }
   chans = new IRC_TCL(NULL);
@@ -637,7 +637,7 @@ void Auth_Rem(void *ticket, uint8 auth)
   else
     temp = (Auth_PUser)(ticket);
   if (temp==NULL) {
-    fputs("Error, null ticket on logout or no master!\n", stderr);
+    Util_Eputs("Error, null ticket on logout or no master!\n");
     return ;
   }
   IRC_PCL chans;
@@ -656,7 +656,7 @@ void Auth_TUHCB::UHCR(const char *nick, const char *user, const char *host)
 {
   // This is the response to a Userhost challenge.
 #ifdef DEBUG
-  fputs("DEBUG - Auth_TUHCB::UHCR called\n", stderr);
+  Util_Eputs("DEBUG - Auth_TUHCB::UHCR called\n");
 #endif
   Auth_PUHCB temp;
   for (temp=first;temp!=NULL;temp=temp->GetNext())
@@ -680,8 +680,7 @@ void Auth_Nick(const char *prefix, const char *nick)
     if (ticket!=NULL)
       ticket->ChangeTracking(nick);
     else
-      fputs("Error: No matching user or tracking ticket on nick change.\n",
-	    stderr);
+      Util_Eputs("Error: No matching user or tracking ticket on nick change.\n");
   }
 }
 
@@ -761,7 +760,7 @@ void Auth_DCCLost(void *cookie)
   if (temp==NULL) {  // This shouldn't happen
     temp = Auth_TUser::MatchDCCCookie(cookie, TRUE);
     if (temp==NULL) { // This REALLY shouldn't happen
-      fputs("Auth_DCCLost: Missing DCC Cookie.\n", stderr);
+      Util_Eputs("Auth_DCCLost: Missing DCC Cookie.\n");
       return ;
     }
   }
@@ -846,7 +845,7 @@ Auth_PUser Auth_TUser::MatchDCCCookie(void *cookie, TF flag)
 void Auth_Init()
 {
 #ifdef DEBUG
-  fputs("DEBUG - Auth_Init called\n", stderr);
+  Util_Eputs("DEBUG - Auth_Init called\n");
 #endif
   LD_AuthGetUsers();
   Cmd_Init();
@@ -855,7 +854,7 @@ void Auth_Init()
 void Auth_Cleanup()
 {
 #ifdef DEBUG
-  fputs("DEBUG - Auth_Cleanup called\n", stderr);
+  Util_Eputs("DEBUG - Auth_Cleanup called\n");
 #endif
   LD_AuthDumpUsers();
   Auth_TTicket::FlushList();
@@ -885,7 +884,7 @@ void Auth_CmdResult(void *ticket, uint8 auth, const char *message)
     Auth_TUser::GetMaster()->SendMessage(message);
     return;
   default:
-    fprintf(stderr, "Error: Invalid auth level: %d\n", auth);
+    Util_Eprintf("Error: Invalid auth level: %d\n", auth);
   }
 }
 
@@ -893,7 +892,7 @@ void Auth_DCCMessage(void *cookie, const char *message)
 {
   Auth_PUser temp = Auth_TUser::MatchDCCCookie(cookie);
   if (temp==NULL) {
-    fputs("DCC message received from unmatched cookie!", stderr);
+    Util_Eputs("DCC message received from unmatched cookie!");
     return ;
   }
   if (temp == Auth_TUser::GetMaster())
@@ -931,7 +930,7 @@ void Auth_NotifyMaster(const char *message)
 {
   Auth_PUser temp = Auth_TUser::GetMaster();
   if (temp==NULL) {
-    fputs("Auth_NotifyMaster: No master present in userlist!\n", stderr);
+    Util_Eputs("Auth_NotifyMaster: No master present in userlist!\n");
     return;
   }
   temp->SendMessage(message);
@@ -946,7 +945,7 @@ void Auth_TUHCB::FlushList()
 Auth_TUHCB::Auth_TUHCB(void (*fun)(Auth_PUHCB), const char *s_nick)
 {
 #ifdef DEBUG
-  fputs("DEBUG - Auth_TUHCB ctor called\n", stderr);
+  Util_Eputs("DEBUG - Auth_TUHCB ctor called\n");
 #endif
   if (last!=NULL) {
     prev = last;
@@ -966,7 +965,7 @@ Auth_TUHCB::Auth_TUHCB(void (*fun)(Auth_PUHCB), const char *s_nick)
 void Auth_TUHCB::Delete(Auth_PUHCB uhcb)
 {
 #ifdef DEBUG
-  fputs("DEBUG - Auth_TUHCB::Delete called\n", stderr);
+  Util_Eputs("DEBUG - Auth_TUHCB::Delete called\n");
 #endif
   if (uhcb->prev!=NULL)
     uhcb->prev->next = uhcb->next;
