@@ -21,6 +21,7 @@
 #include "../utils.h"
 #include "../auth.h"
 #include "../log.h"
+#include "../config.h"
 
 extern char *irc_curchan;
 
@@ -70,6 +71,14 @@ void Cmd_Actions_Root(void *ticket, int auth, const char *str)
     Cmd_Auth_Root(ticket, auth, data);
     return ;
   }
+  if (strcasecmp(cmd, "ROLL")==0) {
+    Cmd_Roll_Root(ticket, auth, data);
+    return ;
+  }
+  if (strcasecmp(cmd, "WROLL")==0) {
+    Cmd_WRoll_Root(ticket, auth, data);
+    return ;
+  }
   if (auth<CMD_AUTH_USER) {
     Auth_CmdResult(ticket, auth, "You are not an authorized user.");
     return ;
@@ -114,10 +123,6 @@ void Cmd_Actions_Root(void *ticket, int auth, const char *str)
       Cmd_Log_Root(ticket, auth, data);
     return ;
   }
-  if (strcasecmp(cmd, "ROLL")==0) {
-    Cmd_Roll_Root(ticket, auth, data);
-    return ;
-  }
 #endif
   if (strcasecmp(cmd, "MSG")==0) {
 #ifdef RPGSERV
