@@ -16,6 +16,7 @@
 #include "../types.h"
 #include "../alloc.h"
 #include "../lachesis.h"
+#include "../config.h"
 
 extern TF log_active;
 extern FILE *log_file;
@@ -68,9 +69,22 @@ void Cmd_Log_Root(void *ticket, int auth, const char *str)
 	free(options.logfile);
       options.logfile = strdup(data);
       Log_Init();
+      if (log_file==NULL)
+	Auth_CmdResult(ticket, auth, "Invalid or existing filename.");
+      else
+	Auth_CmdResult(ticket, auth, "Log opened.");
     }
     return ;
   }
+  if (strcasecmp(cmd, "CLOSE")==0) {
+    Log_Cleanup();
+    if (options.logfile!=NULL) {
+      free(options.logfile);
+      options.logfile = NULL;
+    }
+    Auth_CmdResult(ticket, auth, "Log closed.");
+    return ;
+  }
   if (strcasecmp(cmd, "ON")==0) {
     if (log_file==NULL)
       Auth_CmdResult(ticket, auth, "No logfile open.");
