@@ -1,6 +1,6 @@
 /*
- * Lachesis, an IRCRPG combat engine - Message-based IRC Interface
- * Copyright 2002 M. Dennis
+ * Lachesis, an IRCRPG combat engine - Native IRC Interface
+ * Copyright 2002-2003 M. Dennis
  *
  * This interface creates a native low-level interface to an IRC server.
  * It also handles DCC CHAT connections. At this time,  DCC SEND is not
@@ -26,6 +26,7 @@
 #include "utils.h"
 #include "alloc.h"
 #include "ircint.h"
+#include "config.h"
 
 fd_set *lin_read_fds = NULL;
 int lin_fd = -1;
@@ -128,7 +129,7 @@ void AcceptDCC(PDCC dcc)
   asock = accept(dcc->sock, (struct sockaddr *)&(dcc->addr), 
 		 &(dcc->addrlen));
   if (asock<0) {
-    fprintf(stderr, "AcceptDCC: Unable to accept connection: %m\n");
+    Util_Eprintf("AcceptDCC: Unable to accept connection: %m\n");
     return ;
   }
 
@@ -169,7 +170,7 @@ void PrefixSeparate()
 void IRC_Userhost(const char *target)
 {
 #ifdef DEBUG
-  fprintf(stderr, "DEBUG - IRC USERHOST %s\n", target);
+  Util_Eprintf("DEBUG - IRC USERHOST %s\n", target);
 #endif
   fdprintf(lin_fd, "USERHOST %s\r\n", target);
   //  FD_SET(fileno(icsout), write_fds);
@@ -179,7 +180,7 @@ void IRC_Quote(const char *str, TF priority)
 {
   // priority is currently unused.
 #ifdef DEBUG
-  fprintf(stderr, "DEBUG - Sending to server: %s\n", str);
+  Util_Eprintf("DEBUG - Sending to server: %s\n", str);
 #endif
   fdprintf(lin_fd, "%s\r\n", str);
   //  FD_SET(fileno(icsout), write_fds);
@@ -188,7 +189,7 @@ void IRC_Quote(const char *str, TF priority)
 void IRC_Notice(const char *target, const char *message)
 {
 #ifdef DEBUG
-  fprintf(stderr, "DEBUG - IRC NOTICE %s %s\n", target, message);
+  Util_Eprintf("DEBUG - IRC NOTICE %s %s\n", target, message);
 #endif
   fdprintf(lin_fd, "NOTICE %s :%s\r\n", target, message);
   //  FD_SET(fileno(icsout), write_fds);
@@ -198,12 +199,12 @@ void IRC_Part(const char *channel, const char *message)
 {
   if (message!=NULL&&*message) {
 #ifdef DEBUG
-    fprintf(stderr, "DEBUG - IRC PART %s :%s\n", channel, message);
+    Util_Eprintf("DEBUG - IRC PART %s :%s\n", channel, message);
 #endif
     fdprintf(lin_fd, "PART %s :%s\r\n", channel, message);
   } else {
 #ifdef DEBUG
-    fprintf(stderr, "DEBUG - IRC PART %s\n", channel);
+    Util_Eprintf("DEBUG - IRC PART %s\n", channel);
 #endif
     fdprintf(lin_fd, "PART %s\r\n", channel);
   }
@@ -214,12 +215,12 @@ void IRC_CTCP(const char *target, const char *command, const char *data)
 {
   if (data!=NULL) {
 #ifdef DEBUG
-    fprintf(stderr, "DEBUG - IRC CTCP %s %s %s\n", target, command, data);
+    Util_Eprintf("DEBUG - IRC CTCP %s %s %s\n", target, command, data);
 #endif
     fdprintf(lin_fd, "PRIVMSG %s :%c%s %s%c\r\n", target, 1, command, data, 1);
   } else {
 #ifdef DEBUG
-    fprintf(stderr, "DEBUG - IRC CTCP %s %s\n", target, command);
+    Util_Eprintf("DEBUG - IRC CTCP %s %s\n", target, command);
 #endif
     fdprintf(lin_fd, "PRIVMSG %s :%c%s%c\r\n", target, 1, command, 1);
   }
@@ -239,7 +240,7 @@ const char * IRC_VersionInfo()
 void IRC_Nick(const char *nick)
 {
 #ifdef DEBUG
-  fprintf(stderr, "DEBUG - IRC NICK %s\n", nick);
+  Util_Eprintf("DEBUG - IRC NICK %s\n", nick);
 #endif
   fdprintf(lin_fd, "NICK %s\r\n", nick);
   //  FD_SET(fileno(icsout), write_fds);
@@ -248,7 +249,7 @@ void IRC_Nick(const char *nick)
 void IRC_Public(const char *channel, const char *message)
 {
 #ifdef DEBUG
-  fprintf(stderr, "DEBUG - IRC PUBLIC %s %s\n", channel, message);
+  Util_Eprintf("DEBUG - IRC PUBLIC %s %s\n", channel, message);
 #endif
   fdprintf(lin_fd, "PRIVMSG %s :%s\r\n", channel, message);
   //  FD_SET(fileno(icsout), write_fds);
@@ -262,7 +263,7 @@ void IRC_Action(const char *channel, const char *message)
 void IRC_MSG(const char *target, const char *message)
 {
 #ifdef DEBUG
-  fprintf(stderr, "DEBUG - IRC MSG %s %s\n", target, message);
+  Util_Eprintf("DEBUG - IRC MSG %s %s\n", target, message);
 #endif
   fdprintf(lin_fd, "PRIVMSG %s :%s\r\n", target, message);
   //  FD_SET(fileno(icsout), write_fds);
@@ -276,7 +277,7 @@ void IRC_Describe(const char *target, const char *message)
 void IRC_Wallop(const char *message)
 {
 #ifdef DEBUG
-  fprintf(stderr, "DEBUG - IRC WALLOP %s\n", message);
+  Util_Eprintf("DEBUG - IRC WALLOP %s\n", message);
 #endif
   fdprintf(lin_fd, "WALLOPS :%s\r\n", message);
   //  FD_SET(fileno(icsout), write_fds);
@@ -286,12 +287,12 @@ void IRC_Join(const char *channel, const char *key)
 {
   if (key!=NULL) {
 #ifdef DEBUG
-    fprintf(stderr, "DEBUG - IRC JOIN %s %s\n", channel, key);
+    Util_Eprintf("DEBUG - IRC JOIN %s %s\n", channel, key);
 #endif
     fdprintf(lin_fd, "JOIN %s %s\r\n", channel, key);
   } else {
 #ifdef DEBUG
-    fprintf(stderr, "DEBUG - IRC JOIN %s\n", channel);
+    Util_Eprintf("DEBUG - IRC JOIN %s\n", channel);
 #endif
     fdprintf(lin_fd, "JOIN %s\r\n", channel);
   }
@@ -301,11 +302,15 @@ void IRC_Join(const char *channel, const char *key)
 void IRC_Quit(const char *message)
 {
 #ifdef DEBUG
-  fprintf(stderr, "DEBUG - IRC QUIT %s\n", message);
+  Util_Eprintf("DEBUG - IRC QUIT %s\n", message);
 #endif
   fdprintf(lin_fd, "QUIT :%s\r\n", message);
+  IRC_Shutdown();
+}
+
+void IRC_Shutdown() {
 #ifdef DEBUG
-  fputs("DEBUG - Closing IRC server connection\n", stderr);
+  Util_Eputs("DEBUG - Closing IRC server connection\n");
 #endif
   close(lin_fd);
   lin_fd = -1;
@@ -367,11 +372,11 @@ void * IRC_DCCChatSend(const char *target)
   char buffer[ALLOC_MINIBUFFER];
 
 #ifdef DEBUG
-  fprintf(stderr, "DEBUG - IRC DCC CHAT %s\n", target);
+  Util_Eprintf("DEBUG - IRC DCC CHAT %s\n", target);
 #endif
   sock = socket(PF_INET, SOCK_STREAM, 0);
   if (sock<0) {
-    fprintf(stderr, "IRC_DCCChatSend: Unable to create socket: %m\n");
+    Util_Eprintf("IRC_DCCChatSend: Unable to create socket: %m\n");
     return NULL;
   }
   sin.sin_family = AF_INET;
@@ -380,18 +385,18 @@ void * IRC_DCCChatSend(const char *target)
   len = 1;
   setsockopt(sock, SOL_SOCKET, SO_REUSEADDR, (void *)(&len), sizeof(len));
   if (bind(sock, (struct sockaddr *)(&sin), sizeof(struct sockaddr_in))<0) {
-    fprintf(stderr, "IRC_DCCChatSend: Unable to bind socket: %m\n");
+    Util_Eprintf("IRC_DCCChatSend: Unable to bind socket: %m\n");
     close (sock);
     return NULL;
   }
   len = sizeof(struct sockaddr_in);
   if (getsockname(sock, (struct sockaddr *)(&sin), &len)<0) {
-    fprintf(stderr, "IRC_DCCChatSend: Unable to read address: %m\n");
+    Util_Eprintf("IRC_DCCChatSend: Unable to read address: %m\n");
     close (sock);
     return NULL;
   }
   if (listen(sock, 1)<0) {
-    fprintf(stderr, "IRC_DCCChatSend: Unable to listen: %m\n");
+    Util_Eprintf("IRC_DCCChatSend: Unable to listen: %m\n");
     close (sock);
     return NULL;
   }
@@ -407,16 +412,16 @@ void IRC_DCCChatAccept(void *cookie)
   int sock, ioflags;
 
 #ifdef DEBUG
-  fprintf(stderr, "DEBUG - IRC DCC CHAT ACCEPT %s\n", ((PDCC)cookie)->nick);
+  Util_Eprintf("DEBUG - IRC DCC CHAT ACCEPT %s\n", ((PDCC)cookie)->nick);
 #endif
   sock = socket(PF_INET, SOCK_STREAM, 0);
   if (sock<0) {
-    fprintf(stderr, "IRC_DCCChatAccept: Unable to create socket: %m\n");
+    Util_Eprintf("IRC_DCCChatAccept: Unable to create socket: %m\n");
     return ;
   }
   if (connect(sock, (struct sockaddr *)&(((PDCC)cookie)->addr), 
               ((PDCC)cookie)->addrlen)<0) {
-    fprintf(stderr, "IRC_DCCChatAccept: Unable to connect: %m\n");
+    Util_Eprintf("IRC_DCCChatAccept: Unable to connect: %m\n");
     close (sock);
     return ;
   }
@@ -433,7 +438,7 @@ void IRC_DCCChatAccept(void *cookie)
 void IRC_DCCChatReject(void *cookie)
 {
 #ifdef DEBUG
-  fprintf(stderr, "DEBUG - IRC DCC CHAT REJECT %s\n", ((PDCC)cookie)->nick);
+  Util_Eprintf("DEBUG - IRC DCC CHAT REJECT %s\n", ((PDCC)cookie)->nick);
 #endif
   IRC_CTCPReply(((PDCC)cookie)->nick, "ERRMSG", "DCC CHAT chat declined");
   RemDCC((PDCC)cookie);
@@ -442,7 +447,7 @@ void IRC_DCCChatReject(void *cookie)
 void IRC_DCCChatMessage(void *cookie, const char *message)
 {
 #ifdef DEBUG
-  fprintf(stderr, "DEBUG - IRC DCC MSG %s %s\n", ((PDCC)cookie)->nick, message);
+  Util_Eprintf("DEBUG - IRC DCC MSG %s %s\n", ((PDCC)cookie)->nick, message);
 #endif
   fdprintf(((PDCC)cookie)->sock, "%s\n", message);
   //  FD_SET(fileno(((PDCC)cookie)->dccout), write_fds);
@@ -451,7 +456,7 @@ void IRC_DCCChatMessage(void *cookie, const char *message)
 void IRC_DCCChatClose(void *cookie)
 {
 #ifdef DEBUG
-  fprintf(stderr, "DEBUG - IRC DCC CHAT CLOSE%s\n", ((PDCC)cookie)->nick);
+  Util_Eprintf("DEBUG - IRC DCC CHAT CLOSE%s\n", ((PDCC)cookie)->nick);
 #endif
   RemDCC((PDCC)cookie);
 }
@@ -464,9 +469,9 @@ const char * IRC_DCCGetNick(void *cookie)
 void IRC_DCCSend(const char *target, const char *fn)
 {
 #ifdef DEBUG
-  fprintf(stderr, "DEBUG - IRC DCC SEND %s %s\n", target, fn);
+  Util_Eprintf("DEBUG - IRC DCC SEND %s %s\n", target, fn);
 #endif
-  fputs("DCC SEND not implemented.\n", stderr);
+  Util_Eputs("DCC SEND not implemented.\n");
 }
 
 void OnDCCChatClose(PDCC dcc)
@@ -510,9 +515,8 @@ void OnNumeric(const char *str)
   switch (num) {
   case RPL_WELCOME:
     if (!lin_registering)
-      fprintf(stderr, 
-	      "Received welcome, but we're not registering!\n(%d) %s\n", 
-	      num, temp);
+      Util_Eprintf("Received welcome, but we're not registering!\n(%d) %s\n", 
+		   num, temp);
     else {
       Util_Copy(lin_our_server, lin_prefix, ALLOC_HOST);
       fdprintf(lin_fd, "USERHOST %s\r\n", lin_our_nick);
@@ -530,8 +534,8 @@ void OnNumeric(const char *str)
       if (ptr2!=NULL)
 	*ptr2 = '\0';
 #ifdef DEBUG
-      fprintf(stderr, "DEBUG - RPL_USERHOST for %s while registering.\n",
-	      nick);
+      Util_Eprintf("DEBUG - RPL_USERHOST for %s while registering.\n",
+		   nick);
 #endif
       if (strcasecmp(nick, lin_our_nick)==0) {
 	ptr1++;
@@ -551,7 +555,7 @@ void OnNumeric(const char *str)
     s2 = (const char *)temp;
     Util_SepTo(chan, ALLOC_CHAN, &s2, 32);
     if (s2==NULL) {
-      fprintf(stderr, "Error: Invalid RPL_NAMREPLY message: %s\n", temp);
+      Util_Eprintf("Error: Invalid RPL_NAMREPLY message: %s\n", temp);
       return ;
     }
     /* Tiamat seems to pass a character before the channel indicating
@@ -561,7 +565,7 @@ void OnNumeric(const char *str)
     if (*chan!='#' && *chan!='&' && *chan!='+')
       Util_SepTo(chan, ALLOC_CHAN, &s2, 32);
     if (s2==NULL) {
-      fprintf(stderr, "Error: Invalid RPL_NAMREPLY message: %s\n", temp);
+      Util_Eprintf("Error: Invalid RPL_NAMREPLY message: %s\n", temp);
       return ;
     }
     if (*s2 != ':') {
@@ -591,7 +595,7 @@ void OnNumeric(const char *str)
       return ;
     }
   case ERR_YOUREBANNEDCREEP:
-    fprintf(stderr, "Error: Banned from server: (%d) %s\n", num, temp);
+    Util_Eprintf("Error: Banned from server: (%d) %s\n", num, temp);
     close(lin_fd);
     lin_fd=-1;
     lin_active=FALSE;
@@ -603,7 +607,7 @@ void OnNumeric(const char *str)
   case ERR_PASSWDMISMATCH:
   case ERR_NUMERICERROR:
 #ifdef DEBUG
-    fprintf(stderr, "DEBUG: (%d) %s\n", num, temp);
+    Util_Eprintf("DEBUG: (%d) %s\n", num, temp);
 #endif
   default:
     HandleNumeric(num, temp);
@@ -612,7 +616,7 @@ void OnNumeric(const char *str)
 
 void OnUnknown(const char *cmd, const char *str)
 {
-  fprintf(stderr, "Unknown event from %s : %s %s\n", lin_prefix, cmd, str);
+  Util_Eprintf("Unknown event from %s : %s %s\n", lin_prefix, cmd, str);
 }
 
 void OnNotice(const char *str)
@@ -634,7 +638,7 @@ void OnNotice(const char *str)
     return ;
   }
 #ifdef DEBUG
-  fprintf(stderr, "Warning: Notice without final parm %s %s\n", target, t2);
+  Util_Eprintf("Warning: Notice without final parm %s %s\n", target, t2);
 #endif
   t1 = strchr(t2, 32);
   if (t1==NULL) {
@@ -675,8 +679,8 @@ void OnDCC(const char *str) {
     dcc_list->addr.sin_addr.s_addr = htonl(addr);
     dcc_list->addr.sin_port = htons(port);
 #ifdef DEBUG
-    fprintf(stderr, "DCC CHAT to %s:%u\n", inet_ntoa(dcc_list->addr.sin_addr),
-	    port);
+    Util_Eprintf("DCC CHAT to %s:%u\n", inet_ntoa(dcc_list->addr.sin_addr),
+		 port);
 #endif
     *strchr(lin_prefix, 0) = '!';
     *strchr(lin_prefix, 0) = '@';
@@ -736,8 +740,8 @@ void OnMSG(const char *str)
     temp++;
 #ifdef DEBUG
   else
-    fprintf(stderr, "Warning: MSG without final parm %s %s\n", lin_prefix, 
-	    str);
+    Util_Eprintf("Warning: MSG without final parm %s %s\n", lin_prefix, 
+		 str);
 #endif
   if (*temp == 1) {
     char buf[ALLOC_BUFFER], *ptr;
@@ -836,7 +840,7 @@ void OnError(const char *str)
     return;
   }
 #ifdef DEBUG
-  fprintf(stderr, "DEBUG - Received Error: %s\n", temp);
+  Util_Eprintf("DEBUG - Received Error: %s\n", temp);
 #endif
 }
 
@@ -880,7 +884,7 @@ void StartMessage()
   PDCC dcc;
   while (1) {
 #ifdef DEBUG
-    fputs("DEBUG - Top of StartMessage loop.\n", stderr);
+    Util_Eputs("DEBUG - Top of StartMessage loop.\n");
 #endif
     memcpy(&reads, lin_read_fds, sizeof(fd_set));
     //    memcpy(&writes, write_fds, sizeof(fd_set));
@@ -905,15 +909,16 @@ void StartMessage()
     if (FD_ISSET(lin_fd, &reads)) {
       char *ptr;
       if (fdgetline(&lin_input, &lin_input_len, lin_fd)<0) {
-	fprintf(stderr, "Error reading socket: %m\n");
-	exit (255);
+	Util_Eprintf("Error reading socket: %m\n");
+	// This is normal for a lost connection. Normal shutdown.
+	IRC_Shutdown();
       }
       *(strchr(lin_input, '\n'))=0;
       ptr = strchr(lin_input, '\r');
       if (ptr!=NULL)
 	*ptr = 0;
 #ifdef DEBUG
-      fprintf(stderr, "DEBUG - Received from server: %s\n", lin_input);
+      Util_Eprintf("DEBUG - Received from server: %s\n", lin_input);
 #endif
       if (lin_input[0]==':') {
 	ptr = lin_input + 1;
@@ -956,7 +961,7 @@ void IRC_Connect(const char *server, const int port, const char *nick,
   socklen_t slen;
 
 #ifdef DEBUG
-  fputs("DEBUG - IRC_Connect called\n", stderr);
+  Util_Eputs("DEBUG - IRC_Connect called\n");
 #endif
 
   lin_read_fds = (fd_set *)malloc(sizeof(fd_set));
@@ -970,25 +975,25 @@ void IRC_Connect(const char *server, const int port, const char *nick,
 
   sock = socket(PF_INET, SOCK_STREAM, 0);
   if (sock<0) {
-    fprintf(stderr, "Failed to create socket: %m\n");
+    Util_Eprintf("Failed to create socket: %m\n");
     exit (1);
   }
   sin.sin_family=AF_INET;
   if (!inet_aton(server, &(sin.sin_addr))) {
     host = gethostbyname2(server, AF_INET);
     if (host==NULL) {
-      fprintf(stderr, "Unable to resolve host: %s\n", server);
+      Util_Eprintf("Unable to resolve host: %s\n", server);
       exit (1);
     }
     sin.sin_addr.s_addr = *((unsigned long *)host->h_addr);
 #ifdef DEBUG
-    fprintf(stderr, "DEBUG - Using resolved address %s\n",
-	    inet_ntoa(sin.sin_addr));
+    Util_Eprintf("DEBUG - Using resolved address %s\n",
+		 inet_ntoa(sin.sin_addr));
 #endif
   }
   sin.sin_port = htons(port);
   if (connect(sock, (struct sockaddr *)&sin, sizeof(sin))<0) {
-    fprintf(stderr, "Failed to connect: %m\n");
+    Util_Eprintf("Failed to connect: %m\n");
     exit (1);
   }
   slen = sizeof(sin);
@@ -1004,13 +1009,13 @@ void IRC_Connect(const char *server, const int port, const char *nick,
 
   lin_registering = TRUE;
 #ifdef DEBUG
-  fprintf(stderr, "DEBUG - IRC NICK %s\n", lin_our_nick);
+  Util_Eprintf("DEBUG - IRC NICK %s\n", lin_our_nick);
 #endif
   fdprintf(lin_fd, "NICK %s\r\n", lin_our_nick);
   host = gethostbyaddr((const char *)&lin_our_addr, 4, AF_INET);
 #ifdef DEBUG
-  fprintf(stderr, "DEBUG - IRC USER %s %s %s :%s\n", lin_our_user,
-	  host->h_name, server, lin_our_name);
+  Util_Eprintf("DEBUG - IRC USER %s %s %s :%s\n", lin_our_user,
+	       host->h_name, server, lin_our_name);
 #endif
   fdprintf(lin_fd, "USER %s %s %s :%s\r\n", lin_our_user, host->h_name,
 	   server, lin_our_name);
@@ -1021,7 +1026,7 @@ void IRC_Connect(const char *server, const int port, const char *nick,
 void LowIrcCleanup()
 {
 #ifdef DEBUG
-  fputs("DEBUG - LowIrcCleanup called\n", stderr);
+  Util_Eputs("DEBUG - LowIrcCleanup called\n");
 #endif
   if (lin_input!=NULL) {
     free(lin_input);
