@@ -16,6 +16,7 @@
 #include "utils.h"
 #include "types.h"
 #include "log.h"
+#include "config.h"
 
 extern CmdOpts options;
 extern const char *SOFTWARE_NAME;
@@ -28,30 +29,6 @@ IRC_PCL irc_channels = NULL;
 
 TF irc_interface_active = FALSE;
 
-#ifndef DFL_IRCNICK
-#ifdef RPGSERV
-#define DFL_IRCNICK "RPGServ"
-#else
-#define DFL_IRCNICK "Lachesis"
-#endif
-#endif
-
-#ifndef DFL_IRCNAME
-#ifdef RPGSERV
-#define DFL_IRCNAME "RPG Character or Extra"
-#else
-#define DFL_IRCNAME "Measuring the threads of Fate"
-#endif
-#endif
-
-#ifndef DFL_IRCUSER
-#ifdef RPGSERV
-#define DFL_IRCUSER "rpgserv"
-#else
-#define DFL_IRCUSER "lachesis"
-#endif
-#endif
-
 void ParseRPL_USERHOST(const char *rpl, char *nick, char *user, char *host,
 		       uint8 *flags)
 {
@@ -69,8 +46,8 @@ void ParseRPL_USERHOST(const char *rpl, char *nick, char *user, char *host,
       *flags += UHFLAG_OPER;
   }
   if (olen>=ALLOC_NICK) {
-    fprintf(stderr, "Error: Nick in RPL_USERHOST exceeds ALLOC_NICK-1: %s\n",
-	    str);
+    Util_Eprintf("Error: Nick in RPL_USERHOST exceeds ALLOC_NICK-1: %s\n",
+		 str);
     exit (255);
   }
   if (nick!=NULL)
@@ -83,8 +60,8 @@ void ParseRPL_USERHOST(const char *rpl, char *nick, char *user, char *host,
   t2 = strchr(t1, '@');
   olen = t2 - t1;
   if (olen>=ALLOC_USER) {
-    fprintf(stderr, "Error: User in RPL_USERHOST exceeds ALLOC_USER-1: %s\n",
-	    str);
+    Util_Eprintf("Error: User in RPL_USERHOST exceeds ALLOC_USER-1: %s\n",
+		 str);
     exit (255);
   }
   if (user!=NULL)
@@ -124,7 +101,7 @@ extern "C"
   void ConnectionReady() 
   { 
 #ifdef DEBUG
-    fputs("DEBUG - ConnectionReady called\n", stderr);
+    Util_Eputs("DEBUG - ConnectionReady called\n");
 #endif
     IntConnectionReady(); 
   }
@@ -132,7 +109,7 @@ extern "C"
   void HandleDCCChatRequest(void *cookie, const char *nick)
   {
 #ifdef DEBUG
-    fputs("DEBUG - HandleDCCChatRequest called\n", stderr);
+    Util_Eputs("DEBUG - HandleDCCChatRequest called\n");
 #endif
     Auth_DCCRequest(nick, cookie);
   }
@@ -140,7 +117,7 @@ extern "C"
   void HandleDCCChatRequestPfx(void *cookie, const char *prefix)
   {
 #ifdef DEBUG
-    fputs("DEBUG - HandleDCCChatRequestPfx called\n", stderr);
+    Util_Eputs("DEBUG - HandleDCCChatRequestPfx called\n");
 #endif
     Auth_DCCRequestPfx(prefix, cookie);
   }
@@ -148,7 +125,7 @@ extern "C"
   void HandleDCCChatOpened(void *cookie)
   {
 #ifdef DEBUG
-    fputs("DEBUG - HandleDCCChatOpened called\n", stderr);
+    Util_Eputs("DEBUG - HandleDCCChatOpened called\n");
 #endif
     Auth_DCCEstablished(cookie);
   }
@@ -156,7 +133,7 @@ extern "C"
   void HandleDCCChatClosed(void *cookie)
   {
 #ifdef DEBUG
-    fputs("DEBUG - HandleDCCChatClosed called\n", stderr);
+    Util_Eputs("DEBUG - HandleDCCChatClosed called\n");
 #endif
     Auth_DCCLost(cookie);
   }
@@ -164,7 +141,7 @@ extern "C"
   void HandleDCCChatMessage(void *cookie, const char *message)
   {
 #ifdef DEBUG
-    fputs("DEBUG - HandleDCCChatMessage called\n", stderr);
+    Util_Eputs("DEBUG - HandleDCCChatMessage called\n");
 #endif
     Auth_DCCMessage(cookie, message);
   }
@@ -173,7 +150,7 @@ extern "C"
   {
     const char *temp;
 #ifdef DEBUG
-    fputs("DEBUG - HandleNumeric called\n", stderr);
+    Util_Eputs("DEBUG - HandleNumeric called\n");
 #endif
     // For some reason these messages get padded...
     temp = message;
@@ -183,11 +160,11 @@ extern "C"
     case 302:
       char nick[ALLOC_NICK], user[ALLOC_USER], host[ALLOC_HOST];
 #ifdef DEBUG
-      fputs("DEBUG - Numeric 302 handler\n", stderr);
+      Util_Eputs("DEBUG - Numeric 302 handler\n");
 #endif
       ParseRPL_USERHOST(temp, nick, user, host, NULL);
 #ifdef DEBUG
-      fprintf(stderr, "DEBUG - ParseRPL_USERHOST %s %s %s\n", nick, user, host);
+      Util_Eprintf("DEBUG - ParseRPL_USERHOST %s %s %s\n", nick, user, host);
 #endif
       Auth_Userhost(nick, user, host);
       break;
@@ -197,7 +174,7 @@ extern "C"
   void HandleUserhost(const char *nick, const char *user, const char *host)
   {
 #ifdef DEBUG
-    fputs("DEBUG - HandleUserhost called\n", stderr);
+    Util_Eputs("DEBUG - HandleUserhost called\n");
 #endif
     // Depending on the sophistication of the interface, it may forward
     // USERHOST-requests here, or simply forward 302s as above.
@@ -207,7 +184,7 @@ extern "C"
   void HandleNotice(const char *prefix, const char *target, const char *message)
   {
 #ifdef DEBUG
-    fputs("DEBUG - HandleNotice called\n", stderr);
+    Util_Eputs("DEBUG - HandleNotice called\n");
 #endif
     if (strcasecmp(IRC_HostmaskNick(prefix), "NICKSERV")==0) {
       if (strcasecmp(IRC_HostmaskUser(prefix), "SERVICES")==0) {
@@ -226,7 +203,7 @@ extern "C"
     const char *command;
 
 #ifdef DEBUG
-    fputs("DEBUG - HandleCTCP called\n", stderr);
+    Util_Eputs("DEBUG - HandleCTCP called\n");
 #endif
     data = message;
     command = Util_Separate(&data, 32);
@@ -298,7 +275,7 @@ extern "C"
   void HandleCTCPReply(const char *prefix, const char *message)
   {
 #ifdef DEBUG
-    fputs("DEBUG - HandleCTCPReply called\n", stderr);
+    Util_Eputs("DEBUG - HandleCTCPReply called\n");
 #endif
     // TODO: handle any legitimate CTCP replies
   }
@@ -307,7 +284,7 @@ extern "C"
   {
     int c;
 #ifdef DEBUG
-    fputs("DEBUG - HandleNames called\n", stderr);
+    Util_Eputs("DEBUG - HandleNames called\n");
 #endif
 
     if (!HLIRC_CheckChan(channel))
@@ -323,7 +300,7 @@ extern "C"
   void HandleName(const char *channel, const char *name)
   {
 #ifdef DEBUG
-    fprintf(stderr, "DEBUG - HandleName called: %s %s\n", channel, name);
+    Util_Eprintf("DEBUG - HandleName called: %s %s\n", channel, name);
 #endif
     if (!HLIRC_CheckChan(channel))
       return ;
@@ -339,7 +316,7 @@ extern "C"
   void HandleInvite(const char *prefix, const char *channel)
   {
 #ifdef DEBUG
-    fputs("DEBUG - HandleInvite called\n", stderr);
+    Util_Eputs("DEBUG - HandleInvite called\n");
 #endif
     // TODO: Tie into authentication system
   }
@@ -348,7 +325,7 @@ extern "C"
 		  const char *channel, const char *message)
   {
 #ifdef DEBUG
-    fputs("DEBUG - HandleKick called\n", stderr);
+    Util_Eputs("DEBUG - HandleKick called\n");
 #endif
     if (!HLIRC_CheckChan(channel))  // This shouldn't happen
       return ;
@@ -361,7 +338,7 @@ extern "C"
   void HandleMSG(const char *prefix, const char *message)
   {
 #ifdef DEBUG
-    fputs("DEBUG - HandleMSG called\n", stderr);
+    Util_Eputs("DEBUG - HandleMSG called\n");
 #endif
     Auth_IRCMessage(prefix, message);
   }
@@ -370,7 +347,7 @@ extern "C"
 		    const char *message)
   {
 #ifdef DEBUG
-    fputs("DEBUG - HandlePublic called\n", stderr);
+    Util_Eputs("DEBUG - HandlePublic called\n");
 #endif
     // TODO: Whatever may be necessary
     if (strcasecmp(target, irc_curchan)==0 || options.logother) {
@@ -382,7 +359,7 @@ extern "C"
   void HandleJoined(const char *channel)
   {
 #ifdef DEBUG
-    fputs("DEBUG - HandleJoined called\n", stderr);
+    Util_Eputs("DEBUG - HandleJoined called\n");
 #endif
     Util_Copy(irc_curchan, channel, ALLOC_CHAN);
     HLIRC_AddChan(channel);
@@ -391,7 +368,7 @@ extern "C"
   void HandleJoin(const char *prefix, const char *channel)
   {
 #ifdef DEBUG
-    fputs("DEBUG - HandleJoin called\n", stderr);
+    Util_Eputs("DEBUG - HandleJoin called\n");
 #endif
     Auth_TrackPr(prefix, channel);
   }
@@ -399,7 +376,7 @@ extern "C"
   void HandleOurNickChanged(const char *nick)
   {
 #ifdef DEBUG
-    fputs("DEBUG - HandleOurNickChanged called\n", stderr);
+    Util_Eputs("DEBUG - HandleOurNickChanged called\n");
 #endif
     // TODO: Tie into authentication system if applicable?
   }
@@ -407,7 +384,7 @@ extern "C"
   void HandleNickChange(const char *prefix, const char *nick)
   {
 #ifdef DEBUG
-    fputs("DEBUG - HandleNickChange called\n", stderr);
+    Util_Eputs("DEBUG - HandleNickChange called\n");
 #endif
     Auth_Nick(prefix, nick);
   }
@@ -415,7 +392,7 @@ extern "C"
   void HandlePart(const char *nick, const char *channel, const char *message)
   {
 #ifdef DEBUG
-    fputs("DEBUG - HandlePart called\n", stderr);
+    Util_Eputs("DEBUG - HandlePart called\n");
 #endif
     if (strcasecmp(nick, IRC_GetNick())==0)
       HLIRC_RemChan(channel);
@@ -426,14 +403,14 @@ extern "C"
   void HandleQuit(const char *nick, const char *message)
   {
 #ifdef DEBUG
-    fputs("DEBUG - HandleQuit called\n", stderr);
+    Util_Eputs("DEBUG - HandleQuit called\n");
 #endif
     Auth_Track(nick, NULL, FALSE);
   }
 
   void HandleDisconnect(const char *message) {
 #ifdef DEBUG
-    fputs("DEBUG - HandleDisconnect called\n", stderr);
+    Util_Eputs("DEBUG - HandleDisconnect called\n");
 #endif
     Auth_Disconnect(message);
     HLIRC_CleanChan();
@@ -455,7 +432,7 @@ void HLIRC_BeginIRCInterface()
   char *nick, *name, *user, *server;
   short int port;
 #ifdef DEBUG
-  fputs("DEBUG - HLIRC_BeginIRCInterface called\n", stderr);
+  Util_Eputs("DEBUG - HLIRC_BeginIRCInterface called\n");
 #endif
   Log_Init();
   if (irc_curchan==NULL) {
@@ -492,7 +469,7 @@ void HLIRC_BeginIRCInterface()
 void HLIRC_EndIRCInterface()
 {
 #ifdef DEBUG
-  fputs("DEBUG - HLIRC_EndIRCInterface called\n", stderr);
+  Util_Eputs("DEBUG - HLIRC_EndIRCInterface called\n");
 #endif
   Log_Cleanup();
   irc_interface_active = FALSE;
@@ -512,7 +489,7 @@ void HLIRC_EndIRCInterface()
 void HLIRC_AddChan(const char *channel)
 {
 #ifdef DEBUG
-  fputs("DEBUG - HLIRC_AddChan called\n", stderr);
+  Util_Eputs("DEBUG - HLIRC_AddChan called\n");
 #endif
   irc_channels = new IRC_TCL(irc_channels);
   Util_Copy(irc_channels->chan, channel, ALLOC_CHAN);
@@ -521,7 +498,7 @@ void HLIRC_AddChan(const char *channel)
 void HLIRC_RemChan(const char *channel)
 {
 #ifdef DEBUG
-  fputs("DEBUG - HLIRC_RemChan called\n", stderr);
+  Util_Eputs("DEBUG - HLIRC_RemChan called\n");
 #endif
   if (irc_channels==NULL)
     return ;
@@ -556,7 +533,7 @@ void HLIRC_RemChan(const char *channel)
 TF HLIRC_CheckChan(const char *channel)
 {
 #ifdef DEBUG
-  fputs("DEBUG - HLIRC_CheckChan called\n", stderr);
+  Util_Eputs("DEBUG - HLIRC_CheckChan called\n");
 #endif
   if (irc_channels==NULL)
     return FALSE;
@@ -570,22 +547,22 @@ TF HLIRC_CheckChan(const char *channel)
 void HLIRC_CleanChan()
 {
 #ifdef DEBUG
-    fputs("DEBUG - HLIRC_CleanChan called\n", stderr);
+    Util_Eputs("DEBUG - HLIRC_CleanChan called\n");
 #endif
   if (irc_channels==NULL)
     return ;
 #ifdef DEBUG
-    fputs("DEBUG - HLIRC_CleanChan is calling IRC_TCL::Flush\n", stderr);
+    Util_Eputs("DEBUG - HLIRC_CleanChan is calling IRC_TCL::Flush\n");
 #endif
   IRC_TCL::Flush(irc_channels);
   irc_channels = NULL;
 #ifdef DEBUG
-  fputs("DEBUG - HLIRC_CleanChan is deleting irc_curchan\n", stderr);
+  Util_Eputs("DEBUG - HLIRC_CleanChan is deleting irc_curchan\n");
 #endif
   if (irc_curchan!=NULL)
     *irc_curchan = 0;
 #ifdef DEBUG
-  fputs("DEBUG - HLIRC_CleanChan is calling Auth_FlushTrack\n", stderr);
+  Util_Eputs("DEBUG - HLIRC_CleanChan is calling Auth_FlushTrack\n");
 #endif
   Auth_FlushTrack();
 }
@@ -593,7 +570,7 @@ void HLIRC_CleanChan()
 void HLIRC_Cleanup()
 {
 #ifdef DEBUG
-    fputs("DEBUG - HLIRC_Cleanup called\n", stderr);
+    Util_Eputs("DEBUG - HLIRC_Cleanup called\n");
 #endif
   if (irc_interface_active)
     HLIRC_EndIRCInterface();
