@@ -3,6 +3,7 @@
 
 #include "alloc.h"
 #include "types.h"
+#include "utils.h"
 
 typedef class IRC_TCL {
  private:
@@ -12,13 +13,13 @@ typedef class IRC_TCL {
   inline IRC_TCL(IRC_TCL *top) 
     { 
 #ifdef DEBUG
-      fputs("DEBUG - IRC_TCL ctor called\n", stderr);
+      Util_Eputs("DEBUG - IRC_TCL ctor called\n");
 #endif
       prev = NULL; next = top; if (top!=NULL) top->prev = this; }
   static inline void Delete(IRC_TCL *cl) 
     { 
 #ifdef DEBUG
-      fputs("DEBUG - IRC_TCL::Delete called\n", stderr);
+      Util_Eputs("DEBUG - IRC_TCL::Delete called\n");
 #endif
       if (cl->next!=NULL)
 	cl->next->prev = cl->prev;
@@ -30,7 +31,7 @@ typedef class IRC_TCL {
   static inline void Flush(IRC_TCL *top)
     { 
 #ifdef DEBUG
-      fputs("DEBUG - IRC_TCL::Flush called\n", stderr);
+      Util_Eputs("DEBUG - IRC_TCL::Flush called\n");
 #endif
       if (top->next!=NULL) Flush(top->next); Delete(top); }
 } *IRC_PCL;
