@@ -30,6 +30,7 @@
 #include "utils.h"
 #include "irc.h"
 #include "auth.h"
+#include "config.h"
 
 CmdOpts options;
 
@@ -37,12 +38,12 @@ CmdOpts options;
 char *username;
 #endif
 
-const char *OPTION_SHORT = "PoOLn:N:u:U:Q:c:k:p:l:h::";
+const char *OPTION_SHORT = "DPoOLn:N:u:U:Q:c:k:p:l:h::";
 
 const char *OPTION_LIST = 
   "ircnick:Rn:ircname:RN:ircuser:Ru:userinfo:RU:datadir:R1:quitmsg:RQ:\
 channel:Rc:chankey:Rk:port:Rp:logfile:Rl:logooc:No:logother:NO:nodesccmt:NL:\
-logtitle:R3:help:Oh:pid:NP:";
+logtitle:R3:help:Oh:pid:NP:pubdice:ND:";
 
 const char *SOFTWARE_NAME =
 #ifdef RPGSERV
@@ -97,12 +98,16 @@ Available options:\n\
 	-O, --logother		Log channels other than the current.\n\
 	--logtitle=<title>	Specify title for log.\n\
 \n\
-	-P, --pid		Drop a pid file\n",\
+	-P, --pid		Drop a pid file\n\
+	-D, --pubdice		Use public dice rolls.\n",\
 SOFTWARE_NAME, Lachesis_Version(), Lachesis_CYear(), SOFTWARE_NAME, argv[0],\
 ALLOC_NICK-1, ALLOC_NAME-1, ALLOC_USER-1, ALLOC_CHAN-1, ALLOC_BUFFER-1,\
 ALLOC_BUFFER-1, ALLOC_BUFFER-1, options.datadir)
 
 const char *MAIN_HELP_DETAIL[] = {
+  "D", "pubdice",
+"This will cause the bot to notice the channel instead of the user when\n\
+dice are rolled.\n",
   "P", "pid",
 "This will cause the bot to drop its pid into a file in the current\n\
 directory.\n",
@@ -191,26 +196,30 @@ different directory.\n",
 extern "C" void Shutdown()
 {
 #ifdef DEBUG
-  fputs("DEBUG - Shutdown called\n", stderr);
+  Util_Eputs("DEBUG - Shutdown called\n");
 #endif
   free(options.datadir);
   if (options.logfile!=NULL)
     free(options.logfile);
   Auth_Cleanup();
   HLIRC_Cleanup();
+  if (options.errlog!=NULL)
+    fclose(options.errlog);
   exit (0);
 }
 
 void do_cleanup(int sgl)
 {
 #ifdef DEBUG
-  fputs("DEBUG - do_cleanup called\n", stderr);
+  Util_Eputs("DEBUG - do_cleanup called\n");
 #endif
   free(options.datadir);
   if (options.logfile!=NULL)
     free(options.logfile);
   Auth_Cleanup();
   HLIRC_Cleanup();
+  if (options.errlog!=NULL)
+    fclose(options.errlog);
   signal(sgl, SIG_DFL);
   raise(sgl);
 }
@@ -225,8 +234,19 @@ uint8 main(int argc, char **argv)
   *options.channel = *options.key = *options.userinfo = *options.ircnick =
     *options.ircuser = *options.quitmessage = options.port = 
     *options.logtitle = options.logooc = options.logother = 
-    options.nodesccmt = 0;
+    options.nodesccmt = options.pubdice = 0;
   options.datadir = options.logfile = NULL;
+#ifndef STDERR_LOG_FILE
+  options.errlog = NULL;
+#else
+  options.errlog = fopen(STDERR_LOG_FILE, "wx");
+  if (options.errlog==NULL) {
+    unlink (STDERR_LOG_FILE "~");
+    link (STDERR_LOG_FILE, STDERR_LOG_FILE "~");
+    unlink (STDERR_LOG_FILE);
+    options.errlog = fopen(STDERR_LOG_FILE, "wx");
+  }
+#endif
   srand(time(0));
   ts1 = OPTION_LIST;
   for (c=0;(ts2=strchr(ts1, ':'))!=NULL;c++)
@@ -251,8 +271,8 @@ uint8 main(int argc, char **argv)
       opts[d].has_arg = optional_argument;
       break;
     default:
-      fputs("Error - invalid OPTION_LIST member.\n", stderr);
-      fprintf(stderr, "DEBUG: type %d. count %d. sct %d. name %s. nulres %c.\n", ts2[0], d, c, names[d], (ts2==NULL)?'y':'n');
+      Util_Eputs("Error - invalid OPTION_LIST member.\n");
+      Util_Eprintf("DEBUG: type %d. count %d. sct %d. name %s. nulres %c.\n", ts2[0], d, c, names[d], (ts2==NULL)?'y':'n');
       exit (255);
     }
     opts[d].flag = NULL;
@@ -272,6 +292,9 @@ uint8 main(int argc, char **argv)
     case '3':
       Util_Copy(options.logtitle, optarg, ALLOC_BUFFER);
       break;
+    case 'D':
+      options.pubdice = TRUE;
+      break;
     case 'P':
       {
 	char *fn;
@@ -281,8 +304,8 @@ uint8 main(int argc, char **argv)
 	fp = fopen(fn, "wx");
 	free(fn);
 	if (fp==NULL)
-	  fprintf(stderr, "Unable to write %s.pid\nOur pid is %d\n",
-	          argv[0], getpid());
+	  Util_Eprintf("Unable to write %s.pid\nOur pid is %d\n",
+		       argv[0], getpid());
 	else {
 	  fprintf(fp, "%d\n", getpid());
 	  fclose(fp);
@@ -336,7 +359,7 @@ uint8 main(int argc, char **argv)
     case 'p':
       options.port = strtol(optarg, NULL, 10);
       if (!options.port)
-	fputs("Unable to parse port option; ignoring.\n", stderr);
+	Util_Eputs("Unable to parse port option; ignoring.\n");
       break;
     case 'u':
       Util_Copy(options.ircuser, optarg, ALLOC_USER);
@@ -344,7 +367,7 @@ uint8 main(int argc, char **argv)
     }
   }
   if (optind == argc) {
-    fputs("Error: no server specified.\n", stderr);
+    Util_Eputs("Error: no server specified.\n");
     exit(1);
   }
   Util_Copy(options.server, argv[optind], ALLOC_HOST);
@@ -370,6 +393,6 @@ uint8 main(int argc, char **argv)
   Auth_Init();
   HLIRC_BeginIRCInterface();
   // This should not return.
-  fputs("Error: HLIRC_BeginIRCInterface returned!\n", stderr);
+  Util_Eputs("Error: HLIRC_BeginIRCInterface returned!\n");
   Shutdown();
 }
