@@ -39,6 +39,8 @@ typedef struct tag_cmd_opts {
   TF logooc;
   TF nodesccmt;
   TF logother;
+  TF pubdice;
+  FILE *errlog;
 } CmdOpts;
 
 #ifdef __cplusplus
