@@ -1,6 +1,6 @@
 /*
- * Lachesis - Interface to Parsecfg
- * Copyright 2002 M. Dennis
+ * Lachesis - Interface to filesystem
+ * Copyright 2002-2003 M. Dennis
  *
  * This program is free software; please see the file COPYING for details.
  */
@@ -15,6 +15,7 @@
 #include "alloc.h"
 #include "types.h"
 #include "utils.h"
+#include "config.h"
 
 extern CmdOpts options;
 
@@ -36,7 +37,7 @@ TF LD_AuthGetUsers()
     *strchr(masteracct, '\n') = '\0';
     fclose(in);
   } else {
-    fputs("LoadData: No Master account specified! Failed...\n", stderr);
+    Util_Eputs("LoadData: No Master account specified! Failed...\n");
     return FALSE;
   }
   len = 0;
@@ -44,7 +45,7 @@ TF LD_AuthGetUsers()
   dir = opendir(path);
   free(path);
   if (dir==NULL) {
-    fprintf(stderr, "LoadData: Unexpected error from opendir: %m\n");
+    Util_Eprintf("LoadData: Unexpected error from opendir: %m\n");
     free (masteracct);
     return FALSE;
   }
@@ -57,8 +58,8 @@ TF LD_AuthGetUsers()
     in = fopen(path, "r");
     free(path);
     if (in==NULL) {
-      fprintf(stderr, "LoadData: Error retrieving password for %s: %m\n",
-	      acct);
+      Util_Eprintf("LoadData: Error retrieving password for %s: %m\n",
+		   acct);
       free (masteracct);
       return FALSE;
     }
@@ -103,7 +104,7 @@ TF LD_AuthGetUsers()
   free(masteracct);
   free(input);
   if (Auth_TUser::GetMaster()==NULL) {
-    fputs("LoadData: No account is master! Failed...\n", stderr);
+    Util_Eputs("LoadData: No account is master! Failed...\n");
     return FALSE;
   }
   return TRUE;
@@ -170,7 +171,7 @@ void LD_SetPassword(const char *acct, const char *pass)
   do {
     c++;
     if (c>10) {
-      fprintf(stderr, "File error: unable to write password: %m\n");
+      Util_Eprintf("File error: unable to write password: %m\n");
       free(path);
       return ;
     }
