@@ -11,6 +11,7 @@
 #include "alloc.h"
 #include "log.h"
 #include "utils.h"
+#include "config.h"
 
 extern CmdOpts options;
 FILE *log_file = NULL;
@@ -32,7 +33,7 @@ void Log_Init()
     return;
   log_file = fopen(options.logfile, "wx");
   if (log_file==NULL) {
-    fprintf(stderr, "Failed to create logfile %s: %m\n", options.logfile);
+    Util_Eprintf("Failed to create logfile %s: %m\n", options.logfile);
     return;
   }
   //  log_active = TRUE;
@@ -91,11 +92,12 @@ void Log_FormatLine(char *out, size_t len, const char *in, TF comment) {
     while (in[c]!='\0')
       switch(in[c]) {
       case '-':
-	if (in[c+1]=='-'&&in[c+2]=='>')
+	if (in[c+1]=='-'&&in[c+2]=='>') {
 	  out[d] = out[d+1] = '~';
-	out[d+2] = '>';
-	d+=3;
-	c+=3;
+	  out[d+2] = '>';
+	  d+=3;
+	  c+=3;
+	}
 	break;
       case 2:
       case 15:
@@ -112,7 +114,7 @@ void Log_FormatLine(char *out, size_t len, const char *in, TF comment) {
       case '<':
 	if (d+4>=len) {
 	  out[d] = '\0';
-	  fputs("Log: ALLOC_BUFFER too small!\n", stderr);
+	  Util_Eputs("Log: ALLOC_BUFFER too small!\n");
 	  return ;
 	}
 	strncpy(out+d, "&lt;", 4);
@@ -122,7 +124,7 @@ void Log_FormatLine(char *out, size_t len, const char *in, TF comment) {
       case '>':
 	if (d+4>=len) {
 	  out[d] = '\0';
-	  fputs("Log: ALLOC_BUFFER too small!\n", stderr);
+	  Util_Eputs("Log: ALLOC_BUFFER too small!\n");
 	  return ;
 	}
 	strncpy(out+d, "&gt;", 4);
@@ -132,7 +134,7 @@ void Log_FormatLine(char *out, size_t len, const char *in, TF comment) {
       case '&':
 	if (d+5>=len) {
 	  out[d] = '\0';
-	  fputs("Log: ALLOC_BUFFER too small!\n", stderr);
+	  Util_Eputs("Log: ALLOC_BUFFER too small!\n");
 	  return ;
 	}
 	strncpy(out+d, "&amp;", 5);
@@ -143,7 +145,7 @@ void Log_FormatLine(char *out, size_t len, const char *in, TF comment) {
 	if (b) {
 	  if (d+4>=len) {
 	    out[d] = '\0';
-	    fputs("Log: ALLOC_BUFFER too small!\n", stderr);
+	    Util_Eputs("Log: ALLOC_BUFFER too small!\n");
 	    return ;
 	  }
 	  strncpy(out+d, "</B>", 4);
@@ -153,7 +155,7 @@ void Log_FormatLine(char *out, size_t len, const char *in, TF comment) {
 	} else {
 	  if (d+3>=len) {
 	    out[d] = '\0';
-	    fputs("Log: ALLOC_BUFFER too small!\n", stderr);
+	    Util_Eputs("Log: ALLOC_BUFFER too small!\n");
 	    return ;
 	  }
 	  strncpy(out+d, "<B>", 3);
@@ -166,7 +168,7 @@ void Log_FormatLine(char *out, size_t len, const char *in, TF comment) {
 	if (t) {
 	  if (d+5>=len) {
 	    out[d] = '\0';
-	    fputs("Log: ALLOC_BUFFER too small!\n", stderr);
+	    Util_Eputs("Log: ALLOC_BUFFER too small!\n");
 	    return ;
 	  }
 	  strncpy(out+d, "</TT>", 5);
@@ -176,7 +178,7 @@ void Log_FormatLine(char *out, size_t len, const char *in, TF comment) {
 	} else {
 	  if (d+4>=len) {
 	    out[d] = '\0';
-	    fputs("Log: ALLOC_BUFFER too small!\n", stderr);
+	    Util_Eputs("Log: ALLOC_BUFFER too small!\n");
 	    return ;
 	  }
 	  strncpy(out+d, "<TT>", 4);
@@ -189,7 +191,7 @@ void Log_FormatLine(char *out, size_t len, const char *in, TF comment) {
 	if (u) {
 	  if (d+4>=len) {
 	    out[d] = '\0';
-	    fputs("Log: ALLOC_BUFFER too small!\n", stderr);
+	    Util_Eputs("Log: ALLOC_BUFFER too small!\n");
 	    return ;
 	  }
 	  strncpy(out+d, "</U>", 4);
@@ -199,7 +201,7 @@ void Log_FormatLine(char *out, size_t len, const char *in, TF comment) {
 	} else {
 	  if (d+3>=len) {
 	    out[d] = '\0';
-	    fputs("Log: ALLOC_BUFFER too small!\n", stderr);
+	    Util_Eputs("Log: ALLOC_BUFFER too small!\n");
 	    return ;
 	  }
 	  strncpy(out+d, "<U>", 3);
@@ -212,39 +214,43 @@ void Log_FormatLine(char *out, size_t len, const char *in, TF comment) {
 	if (b) {
 	  if (d+4>=len) {
 	    out[d] = '\0';
-	    fputs("Log: ALLOC_BUFFER too small!\n", stderr);
+	    Util_Eputs("Log: ALLOC_BUFFER too small!\n");
 	    return ;
 	  }
 	  strncpy(out+d, "</B>", 4);
 	  d+=4;
+	  b=FALSE;
 	}
 	if (u) {
 	  if (d+4>=len) {
 	    out[d] = '\0';
-	    fputs("Log: ALLOC_BUFFER too small!\n", stderr);
+	    Util_Eputs("Log: ALLOC_BUFFER too small!\n");
 	    return ;
 	  }
 	  strncpy(out+d, "</U>", 4);
 	  d+=4;
+	  u=FALSE;
 	}
 	if (t) {
 	  if (d+5>=len) {
 	    out[d] = '\0';
-	    fputs("Log: ALLOC_BUFFER too small!\n", stderr);
+	    Util_Eputs("Log: ALLOC_BUFFER too small!\n");
 	    return ;
 	  }
 	  strncpy(out+d, "</TT>", 5);
 	  d+=5;
+	  t=FALSE;
 	}
+	c++;
 	break;
       case '*':
 	if (i) {
 	  if (in[c+1]!=' '&&in[c+1]!='.'&&in[c+1]!='!'&&in[c+1]!='?'&&
-	      in[c+1]!='\0')
+	      in[c+1]!='\0'&&in[c+1]!='('&&in[c+1]!=')')
 	    goto nml;
 	  if (d+4>len) {
 	    out[d] = '\0';
-	    fputs("Log: ALLOC_BUFFER too small!\n", stderr);
+	    Util_Eputs("Log: ALLOC_BUFFER too small!\n");
 	    return ;
 	  }
 	  strncpy(out+d, "</I>", 4);
@@ -252,11 +258,11 @@ void Log_FormatLine(char *out, size_t len, const char *in, TF comment) {
 	  c++;
 	  i=FALSE;
 	} else {
-	  if (c!=0&&in[c-1]!=' '&&in[c-1]!='.')
+	  if (c!=0&&in[c-1]!=' '&&in[c-1]!='.'&&in[c-1]!='('&&in[c-1]!=')')
 	    goto nml;
 	  if (d+3>=len) {
 	    out[d] = '\0';
-	    fputs("Log: ALLOC_BUFFER too small!\n", stderr);
+	    Util_Eputs("Log: ALLOC_BUFFER too small!\n");
 	    return ;
 	  }
 	  strncpy(out+d, "<I>", 3);
@@ -271,13 +277,13 @@ void Log_FormatLine(char *out, size_t len, const char *in, TF comment) {
       }
     if (d>=len) {
       out[d] = '\0';
-      fputs("Log: ALLOC_BUFFER too small!\n", stderr);
+      Util_Eputs("Log: ALLOC_BUFFER too small!\n");
       return ;
     }
     if (b) {
       if (d+4>=len) {
 	out[d] = '\0';
-	fputs("Log: ALLOC_BUFFER too small!\n", stderr);
+	Util_Eputs("Log: ALLOC_BUFFER too small!\n");
 	return ;
       }
       strncpy(out+d, "</B>", 4);
@@ -286,7 +292,7 @@ void Log_FormatLine(char *out, size_t len, const char *in, TF comment) {
     if (i) {
       if (d+4>=len) {
 	out[d] = '\0';
-	fputs("Log: ALLOC_BUFFER too small!\n", stderr);
+	Util_Eputs("Log: ALLOC_BUFFER too small!\n");
 	return ;
       }
       strncpy(out+d, "</I>", 4);
@@ -295,7 +301,7 @@ void Log_FormatLine(char *out, size_t len, const char *in, TF comment) {
     if (u) {
       if (d+4>=len) {
 	out[d] = '\0';
-	fputs("Log: ALLOC_BUFFER too small!\n", stderr);
+	Util_Eputs("Log: ALLOC_BUFFER too small!\n");
 	return ;
       }
       strncpy(out+d, "</U>", 4);
@@ -304,7 +310,7 @@ void Log_FormatLine(char *out, size_t len, const char *in, TF comment) {
     if (t) {
       if (d+5>=len) {
 	out[d] = '\0';
-	fputs("Log: ALLOC_BUFFER too small!\n", stderr);
+	Util_Eputs("Log: ALLOC_BUFFER too small!\n");
 	return ;
       }
       strncpy(out+d, "</TT>", 5);
@@ -326,7 +332,7 @@ int Log_ParseType(char *str)
       for(c=1;str[c]!='\0';c++)
 	str[c-1] = str[c];
       str[c-1] = '\0';
-    } else if (strncasecmp(str+1, "OOC) ", 5)==0) {
+    } else if (strncasecmp(str+1, "OOC)", 4)==0) {
       int c,d;
       for (c=6;str[c]!='\0';c++)
 	str[c-6] = str[c];
@@ -337,7 +343,7 @@ int Log_ParseType(char *str)
     goto ooc;
   case 'O':
   case 'o':
-    if (strncasecmp(str+1, "OC: ", 4)==0) {
+    if (strncasecmp(str+1, "OC:", 3)==0) {
       int c,d;
       for (c=5;str[c]!='\0';c++)
 	str[c-5] = str[c];
@@ -375,13 +381,13 @@ void Log_Public(Auth_PUser user, const char *nick, const char *str)
   switch (type) {
   case LOG_OOC:
     if (options.logooc) {
-      Log_FormatLine(out, ALLOC_BUFFER, line, TRUE);
+      Log_FormatLine(out, ALLOC_BUFFER - strlen(nick) - 8, line, TRUE);
       snprintf(line, ALLOC_BUFFER, "OOC - %s: %s", nick, out);
       Log_CommitComment(line);
     }
     break;
   case LOG_FIX:
-    Log_FormatLine(out, ALLOC_BUFFER, line, TRUE);
+    Log_FormatLine(out, ALLOC_BUFFER - strlen(nick) - 3, line, TRUE);
     snprintf(line, ALLOC_BUFFER, "%s - %s", nick, out);
     Log_CommitComment(line);
     break;
@@ -399,7 +405,7 @@ void Log_Public(Auth_PUser user, const char *nick, const char *str)
     Log_CommitDescription(out);
     break;
   case LOG_LINE:
-    Log_FormatLine(out, ALLOC_BUFFER, line, FALSE);
+    Log_FormatLine(out, ALLOC_BUFFER - strlen(nick) - 2, line, FALSE);
     snprintf(line, ALLOC_BUFFER, "%s: %s", nick, out);
     Log_CommitLine(line);
   }
@@ -415,20 +421,20 @@ void Log_Action(const char *nick, const char *str)
   switch (type) {
   case LOG_OOC:
     if (options.logooc) {
-      Log_FormatLine(out, ALLOC_BUFFER, line, TRUE);
+      Log_FormatLine(out, ALLOC_BUFFER - strlen(nick) - 7, line, TRUE);
       snprintf(line, ALLOC_BUFFER, "OOC - %s %s", nick, out);
       Log_CommitComment(line);
     }
     break;
   case LOG_FIX:  /* People shouldn't do this, but we'll support anyway */
-    Log_FormatLine(out, ALLOC_BUFFER, line, TRUE);
+    Log_FormatLine(out, ALLOC_BUFFER - strlen(nick) - 3, line, TRUE);
     snprintf(line, ALLOC_BUFFER, "%s - %s", nick, out);
     Log_CommitComment(line);
     break;
   case LOG_DESC: /* This *really* shouldn't happen */
     Util_Copy(line, str, ALLOC_BUFFER);
   case LOG_LINE:
-    Log_FormatLine(out, ALLOC_BUFFER, line, FALSE);
+    Log_FormatLine(out, ALLOC_BUFFER - strlen(nick) - 1, line, FALSE);
     snprintf(line, ALLOC_BUFFER, "%s %s", nick, out);
     Log_CommitLine(line);
   }
