@@ -7,6 +7,10 @@
 #include <stdio.h>
 #include "alloc.h"
 #include "utils.h"
+#include "lachesis.h"
+#include "config.h"
+
+extern CmdOpts options;
 
 char util_internal_buffer[ALLOC_BUFFER];
 const char util_casediff = 'a' - 'A';
@@ -14,6 +18,7 @@ const char util_casediff = 'a' - 'A';
 #include "utsep.c"
 
 /* g++ 2.95.3 is not liking getline, so we provide a wrapper. */
+// TODO: Might this be affected by _GNU_SOURCE? Test.
 long Util_Getline(char **LINEPTR, size_t *N, FILE *STREAM)
 {
   return getline(LINEPTR, N, STREAM);
@@ -113,6 +118,26 @@ void Util_Cat(char *dst, const char *src, unsigned int size)
   Util_Copy(buf, src, len);
 }
 
+void Util_Eputs(const char *str)
+{
+  fputs(str, stderr);
+  if (options.errlog!=NULL)
+    fputs(str, options.errlog);
+}
+
+void Util_Eprintf(const char *fmt, ...)
+{
+  va_list ap;
+  va_start(ap, fmt);
+  vfprintf(stderr, fmt, ap);
+  va_end(ap);
+  if (options.errlog!=NULL) {
+    va_start(ap, fmt);
+    vfprintf(options.errlog, fmt, ap);
+    va_end(ap);
+  }
+}
+
 char * Util_FormatA(const char *fmt, ...)
 {
   va_list ap;
@@ -122,7 +147,7 @@ char * Util_FormatA(const char *fmt, ...)
   res = vasprintf(&temp, fmt, ap);
   va_end(ap);
   if (res<0) {
-    fputs("Util_FormatA: Allocation error.\n", stderr);
+    Util_Eputs("Util_FormatA: Allocation error.\n");
     return NULL;
   }
   return temp;
@@ -136,7 +161,7 @@ const char * Util_Format(const char *fmt, ...)
   res = vsnprintf(util_internal_buffer, ALLOC_BUFFER, fmt, ap);
   va_end(ap);
   if (res>=ALLOC_BUFFER) {
-    fputs("Util_Format: Buffer allocation is insufficient; message truncated.\n", stderr);
+    Util_Eputs("Util_Format: Buffer allocation is insufficient; message truncated.\n");
     util_internal_buffer[ALLOC_BUFFER-1] = 0;
   }
   return util_internal_buffer;
@@ -147,6 +172,7 @@ const char * Util_FormatD(const char *fmt, const char *arg1, const char *arg2,
 {
   // Wrapper for dealing with situations where one of the arguments may be
   // our own buffer.
+  // Note: This should probably be deprecated in favor of Util_FormatA...
   char *temp;
   if (arg1==NULL)
     return fmt;
@@ -182,7 +208,7 @@ const char * Util_CTCPFmt(const char *arg1, const char *arg2)
   if (arg2!=NULL) {
     temp = strchr(util_internal_buffer, 0);
     if (temp - util_internal_buffer >= ALLOC_BUFFER - 2) {
-      fputs("Util_CTCPFmt: Buffer allocation is insufficient; message truncated.\n", stderr);
+      Util_Eputs("Util_CTCPFmt: Buffer allocation is insufficient; message truncated.\n");
       util_internal_buffer[ALLOC_BUFFER-2] = 1;
       return util_internal_buffer;
     }
@@ -192,7 +218,7 @@ const char * Util_CTCPFmt(const char *arg1, const char *arg2)
   }
   temp = strchr(util_internal_buffer, 0);
   if (util_internal_buffer - temp >= ALLOC_BUFFER - 1) {
-    fputs("Util_CTCPFmt: Buffer allocation is insufficient; message truncated.\n", stderr);
+    Util_Eputs("Util_CTCPFmt: Buffer allocation is insufficient; message truncated.\n");
     util_internal_buffer[ALLOC_BUFFER-2] = 1;
     return util_internal_buffer;
   }
