@@ -22,6 +22,8 @@ int Util_Count(const char *, char);
 void Util_Copy(char *, const char *, unsigned int size);
 void Util_Cat(char *, const char *, unsigned int size);
 void Util_Strip(char *, unsigned int size, TF flag);
+void Util_Eputs(const char *);
+void Util_Eprintf(const char *, ...);
 char * Util_FormatA(const char *, ...);
 const char * Util_Format(const char *, ...);
 const char * Util_FormatD(const char *, const char *, const char *,
